@@ -37,7 +37,7 @@
 
 pref("general.useragent.vendor", "Thunderbird");
 pref("general.useragent.vendorSub", 
-"1.0"
+"1.0.6"
 );
 
 // This is this application's unique identifier used by the Extension System to identify
@@ -45,10 +45,10 @@ pref("general.useragent.vendorSub",
 // this application to the Update server.
 pref("app.id", "{3550f703-e582-4d05-9a08-453d09bdfdc6}");
 pref("app.version", 
-"1.0"
+"1.0.6"
 );
 pref("app.build_id", 
-"0000000000"
+"2005090314"
 );
 pref("app.extensions.version", "1.0");
 
@@ -111,6 +111,7 @@ pref("update.showSlidingNotification", true);   // Windows-only slide-up taskbar
 pref("update.severity", 0); 
 
 pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 /////////////////////////////////////////////////////////////////
 // Overrides of the seamonkey suite mailnews.js prefs
