@@ -1,30 +1,3 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *
- * The contents of this file are subject to the Mozilla Public
- * License Version 1.1 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS
- * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
- * implied. See the License for the specific language governing
- * rights and limitations under the License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is Netscape Communications
- * Corporation.  Portions created by Netscape are
- * Copyright (C) 2000 Netscape Communications Corporation. All
- * Rights Reserved.
- *
- * Contributor(s): 
- *  Stuart Parmenter <pavlov@netscape.com>
- *  Brian Ryner <bryner@brianryner.com>
- *  Jan Varga <varga@nixcorp.com>
- *  Peter Annema <disttsc@bart.nl>
- *  Johann Petrak <johann@ai.univie.ac.at>
- *  Akkana Peck <akkana@netscape.com>
- */
 
 const nsIFilePicker       = Components.interfaces.nsIFilePicker;
 const nsIDirectoryServiceProvider = Components.interfaces.nsIDirectoryServiceProvider;
@@ -94,8 +67,6 @@ function filepickerLoad() {
       (filePickerMode == nsIFilePicker.modeOpenMultiple) ||
       (filePickerMode == nsIFilePicker.modeSave)) {
 
-    treeView.setFilter(filterTypes[0]);
-
     /* build filter popup */
     var filterPopup = document.createElement("menupopup");
 
@@ -117,6 +88,9 @@ function filepickerLoad() {
     filterBox.removeAttribute("hidden");
 
     filterMenuList.selectedIndex = o.filterIndex;
+
+    treeView.setFilter(filterTypes[o.filterIndex]);
+
   } else if (filePickerMode == nsIFilePicker.modeGetFolder) {
     treeView.showOnlyDirectories = true;
   }
@@ -479,16 +453,8 @@ function handleColumnClick(columnID) {
 function onKeypress(e) {
   if (e.keyCode == 8) /* backspace */
     goUp();
-  else if (e.keyCode == 13) { /* enter */
-    var fileList = treeView.selectedFiles;
-    if (fileList.length > 0) {
-      var file = fileList.queryElementAt(0, nsIFile);
-      if (file.isDirectory()) {
-        gotoDirectory(file);
-        e.preventDefault();
-      }
-    }
-  }
+
+  /* enter is handled by the ondialogaccept handler */
 }
 
 function doEnabling() {
@@ -747,7 +713,7 @@ function toggleShowHidden(event) {
 
 // from the current directory and whatever was entered
 // in the entry field, try to make a new path. This
-// uses "/" as the directory separator, "~" as a shortcut
+// uses "/" as the directory seperator, "~" as a shortcut
 // for the home directory (but only when seen at the start
 // of a path), and ".." to denote the parent directory.
 // returns an array of the files listed,
@@ -812,18 +778,7 @@ function processPathEntry(path, fileArray)
   var filePath;
   var file;
 
-  try {
-    file = sfile.clone().QueryInterface(nsILocalFile);
-  } catch(e) {
-    dump("Couldn't clone\n"+e);
-    return false;
-  }
-
-  var tilde_file = file.clone();
-  tilde_file.append("~");
-  if (path[0] == '~' &&                        // Expand ~ to $HOME, except:
-      !(path == "~" && tilde_file.exists()) && // If ~ was entered and such a file exists, don't expand
-      (path.length == 1 || path[1] == "/"))    // We don't want to expand ~file to ${HOME}file
+  if (path[0] == '~') 
     filePath = homeDir.path + path.substring(1);
   else
     filePath = path;
@@ -831,6 +786,13 @@ function processPathEntry(path, fileArray)
   // Unescape quotes
   filePath = filePath.replace(/\\\"/g, "\"");
   
+  try{
+    file = sfile.clone().QueryInterface(nsILocalFile);
+  } catch(e) {
+    dump("Couldn't clone\n"+e);
+    return false;
+  }
+
   if (filePath[0] == '/')   /* an absolute path was entered */
     file.initWithPath(filePath);
   else if ((filePath.indexOf("/../") > 0) ||
